setUpAll property
A test to run before all tests in the group.
This is null if no setUpAll callbacks were declared.
Implementation
final Test? setUpAll;
A test to run before all tests in the group.
This is null if no setUpAll callbacks were declared.
final Test? setUpAll;