trace property
The stack trace for the call to test() or group() that defined this
entry, or null if the entry was defined in a different way.
Implementation
@override
final Trace? trace;
The stack trace for the call to test() or group() that defined this
entry, or null if the entry was defined in a different way.
@override
final Trace? trace;