clone abstract method
Returns a clone of this object without the internal parent reference
set so that it may be attached to a new tree.
Implementation
GroupEntry? clone();
Returns a clone of this object without the internal parent reference
set so that it may be attached to a new tree.
GroupEntry? clone();