location property

TestLocation? get location

An optional location provided to test() or group() to support test frameworks like pkg:test_reflective_loader where the test/group location might not be in trace at the time test() or group() are called.

If null, the location of a test will try to be inferred from trace.

Implementation

TestLocation? get location;