trace property
Trace?
get
trace
The stack trace for the call to test() or group() that defined this
entry, or null if the entry was defined in a different way.
Implementation
Trace? get trace;
The stack trace for the call to test() or group() that defined this
entry, or null if the entry was defined in a different way.
Trace? get trace;