liveTest property
LiveTest
get
liveTest
The live test being driven by the invoker.
This provides a view into the state of the test being executed.
Implementation
LiveTest get liveTest => _controller;
The live test being driven by the invoker.
This provides a view into the state of the test being executed.
LiveTest get liveTest => _controller;