onClose property
Future<void>
get
onClose
A future that completes once the test has been closed.
Implementation
Future<void> get onClose => _onCloseCompleter.future;
A future that completes once the test has been closed.
Future<void> get onClose => _onCloseCompleter.future;