errors property

List<AsyncError> get errors

An unmodifiable list of all errors that have been caught while running this test.

This will be updated before onError fires. These errors are not guaranteed to have the same types as when they were thrown; for example, they may need to be serialized across isolate boundaries. The stack traces will be Chains.

Implementation

List<AsyncError> get errors;