groups property

List<Group> get groups

The groups within which this test is being run, from the outermost to the innermost.

This will always contain at least the implicit top-level group.

Implementation

List<Group> get groups;