isComplete property

bool get isComplete

Returns whether this test has completed.

This is equivalent to state.status being Status.complete.

Note that even if this returns true, the test may still be running code asynchronously. A test is considered complete either once it hits its first error or when all expectAsync callbacks have been called and any returned Future has completed, but it's possible for further processing to happen, which may cause further errors.

Implementation

bool get isComplete => state.status == Status.complete;