onComplete property

Future get onComplete

A Future that completes once the test is complete.

This will complete after onStateChange has fired, and after onError has fired if the test completes because of an error. It's the same as the Future returned by run.

Note that even once this completes, the test may still be running code asynchronously. A test is considered complete either once it hits its first error or when all expectAsync callbacks have been called and any returned Future has completed, but it's possible for further processing to happen, which may cause further errors.

Implementation

Future get onComplete;