run abstract method
Signals that this test should start running as soon as possible.
A test may not start running immediately for various reasons specific to the means by which it's defined. Until it starts running, state will continue to be marked Status.pending.
This returns the same Future as onComplete. It may not be called more than once.
Implementation
Future run();