state property

State get state

The current state of the running test.

This starts as Status.pending and Result.success. It will be updated before onStateChange fires.

Note that even if this is marked Status.complete, the test may still be running code asynchronously. A test is considered complete either once it hits its first error or when all expectAsync callbacks have been called and any returned Future has completed, but it's possible for further processing to happen, which may cause further errors. It's even possible for a test that was marked Status.complete and Result.success to be marked as Result.error later.

Implementation

State get state;