Message class

A message emitted by a test.

A message encompasses any textual information that should be presented to the user. Reporters are encouraged to visually distinguish different message types.

Constructors

Message(MessageType type, String text)
Message.print(String text)
Message.skip(String text)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
type → MessageType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited