State class

The state of a LiveTest.

A test's state is made up of two components, its status and its result. The status represents where the test is in its process of running; the result represents the outcome as far as its known.

Constructors

State(Status status, Result result)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
result Result
The outcome of the test, as far as it's known.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldBeDone bool
Whether a test in this state is expected to be done running code.
no setter
status Status
Where the test is in its process of running.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override