result property
The outcome of the test, as far as it's known.
Note that if status is Status.pending, result will always be Result.success since the test hasn't yet had a chance to fail.
Implementation
final Result result;
The outcome of the test, as far as it's known.
Note that if status is Status.pending, result will always be Result.success since the test hasn't yet had a chance to fail.
final Result result;