clone abstract method

  1. @override
Test? clone()
override

Returns a clone of this object without the internal parent reference set so that it may be attached to a new tree.

Implementation

@override
Test? clone();