filter abstract method

  1. @override
Test? filter(
  1. bool callback(
    1. Test
    )
)
override

Returns a copy of this with all tests that don't match callback removed.

Returns null if this is a test that doesn't match callback or a group where no child tests match callback.

Implementation

@override
Test? filter(bool Function(Test) callback);