load abstract method

LiveTest load(
  1. Suite suite, {
  2. Iterable<Group>? groups,
})

Loads a live version of this test, which can be used to run it a single time.

suite is the suite within which this test is being run. If groups is passed, it's the list of groups containing this test; otherwise, it defaults to just containing suite.group.

Implementation

LiveTest load(Suite suite, {Iterable<Group>? groups});