backend
library
Classes
-
Declarer
-
A class that manages the state of tests as they're declared.
-
Group
-
A group contains one or more tests and subgroups.
-
GroupEntry
-
A Test or Group.
-
Invoker
-
The class responsible for managing the lifecycle of a single local test.
-
LiveTest
-
A runnable instance of a test.
-
Message
-
A message emitted by a test.
-
Metadata
-
Metadata for a test or test suite.
-
PlatformSelector
-
An expression for selecting certain platforms, including operating systems
and browsers.
-
RemoteListener
-
-
Runtime
-
An enum of all Dart runtimes supported by the test runner.
-
StackTraceFormatter
-
A class that tracks how to format a stack trace according to the user's
configuration.
-
StackTraceMapper
-
A class for mapping JS stack traces to Dart stack traces using source maps.
-
State
-
The state of a LiveTest.
-
SuitePlatform
-
The platform on which a test suite is loaded.
-
Test
-
A single test.
-
TestLocation
-
The location of a test or group.
Enums
-
Compiler
-
All the Dart compilers supported by the test runner.