clone method
Returns a clone of this object without the internal parent reference
set so that it may be attached to a new tree.
Implementation
@override
Group? clone() {
var entries = _map((entry) => entry.clone());
return Group(
name,
entries,
metadata: metadata,
trace: trace,
location: location,
// Always clone these because they are being re-parented.
setUpAll: setUpAll?.clone(),
tearDownAll: tearDownAll?.clone(),
);
}