Properties
hashCode
→ int
The hash code for this object.
no setter inherited
location
→ TestLocation ?
An optional location provided to test() or group() to support test
frameworks like pkg:test_reflective_loader where the test/group location
might not be in trace at the time test() or group() are called.
no setter
metadata
→ Metadata
The metadata for the entry, including the metadata from any containing
Group s.
no setter
name
→ String
The name of the entry, including the prefixes from any containing
Group s.
no setter
parent
↔ Group ?
The parent of this entry.
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
trace
→ Trace?
The stack trace for the call to test() or group() that defined this
entry, or null if the entry was defined in a different way.
no setter
Methods
clone ()
→ GroupEntry ?
Returns a clone of this object without the internal parent reference
set so that it may be attached to a new tree.
filter (bool callback (Test ) )
→ GroupEntry ?
Returns a copy of this with all tests that don't match callback
removed.
forPlatform (SuitePlatform platform )
→ GroupEntry ?
Returns a copy of this with all platform-specific metadata resolved.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited