current property
Invoker?
get
current
The current invoker, or null if none is defined.
An invoker is only set within the zone scope of a running test.
Implementation
static Invoker? get current {
// TODO(nweiz): Use a private symbol when dart2js supports it (issue 17526).
return Zone.current[#test.invoker] as Invoker?;
}