LiveTest class abstract
A runnable instance of a test.
This is distinct from Test in order to keep Test immutable. Running a test requires state, and LiveTest provides a view of the state of the test as it runs.
If the state changes, state will be updated before onStateChange fires. Likewise, if an error is caught, it will be added to errors before being emitted via onError. If an error causes a state change, onStateChange will fire before onError. If an error or other state change causes the test to complete, onComplete will complete after onStateChange and onError fire.
Constructors
- LiveTest()
Properties
-
errors
→ List<
AsyncError> -
An unmodifiable list of all errors that have been caught while running
this test.
no setter
-
groups
→ List<
Group> -
The groups within which this test is being run, from the outermost to the
innermost.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- individualName → String
-
The name of this live test without any group prefixes.
no setter
- isComplete → bool
-
Returns whether this test has completed.
no setter
- onComplete → Future
-
A Future that completes once the test is complete.
no setter
-
onError
→ Stream<
AsyncError> -
A stream that emits a new AsyncError whenever an error is caught.
no setter
-
onMessage
→ Stream<
Message> -
A stream that emits messages produced by the test.
no setter
-
onStateChange
→ Stream<
State> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → State
-
The current state of the running test.
no setter
- suite → Suite
-
The suite within which this test is being run.
no setter
- test → Test
-
The running test.
no setter
Methods
-
close(
) → Future - Signals that this test should stop emitting events and release any resources it may have allocated.
-
copy(
) → LiveTest - Loads a copy of this LiveTest that's able to be run again.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future - Signals that this test should start running as soon as possible.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited