shouldBeDone property
bool
get
shouldBeDone
Whether a test in this state is expected to be done running code.
If status is Status.complete and result doesn't indicate an error, a properly-written test case should not be running any more code. However, it may have started asynchronous processes without notifying the test runner.
Implementation
bool get shouldBeDone => status == Status.complete && result.isPassing;