Test class abstract
A single test.
A test is immutable and stateless, which means that it can't be run directly. To run one, load a live version using Test.load and run it using LiveTest.run.
- Implemented types
Constructors
- Test()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → TestLocation?
-
An optional location provided to
test()orgroup()to support test frameworks like pkg:test_reflective_loader where the test/group location might not be in trace at the timetest()orgroup()are called.no setterinherited - metadata → Metadata
-
The metadata for the entry, including the metadata from any containing
Groups.
no setteroverride
- name → String
-
The name of the entry, including the prefixes from any containing
Groups.
no setteroverride
- parent ↔ Group?
-
The parent of this entry.
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trace → Trace?
-
The stack trace for the call to
test()orgroup()that defined this entry, ornullif the entry was defined in a different way.no setteroverride
Methods
-
clone(
) → Test? -
Returns a clone of this object without the internal
parentreference set so that it may be attached to a new tree.override -
filter(
bool callback(Test)) → Test? -
Returns a copy of
thiswith all tests that don't matchcallbackremoved.override -
forPlatform(
SuitePlatform platform) → Test? -
Returns a copy of
thiswith all platform-specific metadata resolved.override -
load(
Suite suite, {Iterable< Group> ? groups}) → LiveTest - Loads a live version of this test, which can be used to run it a single time.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited