filter abstract method
Returns a copy of this with all tests that don't match callback
removed.
Returns null if this is a test that doesn't match callback or a group
where no child tests match callback.
Implementation
@override
Test? filter(bool Function(Test) callback);